@@ -34,6 +34,10 @@ def parse_content(content):
         ttl = int(words[1])
         value = words[4].replace('"', '\\"')
         key = f"{r_name}_{r_type.lower()}".replace("@", "apex")
+
+        if r_type == "SOA":
+            continue
+
         if key[0].isnumeric():
             key = f"_{key}"
         elif key[0] == "*":
@@ -52,18 +56,18 @@ def generate_tf(domain, entries):
     commands = []
     with click.open_file(filename, "w") as f:
         f.write("locals {\n")
-        f.write(f"{tf_name}_records = " + "{\n")
+        f.write(f"  {tf_name}_records = " + "{\n")
 
         for key, record in entries.items():
-            f.write(f"{key} = {{\n")
-            f.write(f'name = "{record.name}"\n')
-            f.write(f'type = "{record.r_type}"\n')
-            f.write(f"ttl = {record.ttl}\n")
-            f.write("values = [\n")
+            f.write(f"    {key} = {{\n")
+            f.write(f'      name = "{record.name}"\n')
+            f.write(f'      type = "{record.r_type}"\n')
+            f.write(f"      ttl  = {record.ttl}\n")
+            f.write("      values = [\n")
             for value in record.values:
-                f.write(f'"{value}",\n')
-            f.write("]\n")
-            f.write("}\n")
+                f.write(f'        "{value}",\n')
+            f.write("      ]\n")
+            f.write("    }\n")
 
             commands.append(
                 "terraform import "
@@ -71,30 +75,35 @@ def generate_tf(domain, entries):
                 f'"{domain}/{record.name}/{record.r_type}"'
             )
 
-        f.write("}\n}\n\n")
+        f.write("  }\n}\n\n")
 
         f.write(f'resource "gandi_livedns_record" "{tf_name}" {{\n')
-        f.write(f"for_each = local.{tf_name}_records\n\n")
-        f.write(f'zone   = "{domain}"\n\n')
-        f.write("name   = each.value.name\n")
-        f.write("ttl    = each.value.ttl\n")
-        f.write("type   = each.value.type\n")
-        f.write("values = each.value.values\n")
+        f.write(f"  for_each = local.{tf_name}_records\n\n")
+        f.write(f'  zone = "{domain}"\n\n')
+        f.write("  name   = each.value.name\n")
+        f.write("  ttl    = each.value.ttl\n")
+        f.write("  type   = each.value.type\n")
+        f.write("  values = each.value.values\n")
         f.write("}\n")
 
     return commands
 
 
-@click.command(no_args_is_help=True)
-@click.option("--domain", "-d", "domains", help="Domain name to fetch from Gandi", multiple=True)
+@click.command()
 @click.option("--version", help="Display version information", is_flag=True)
+@click.argument("domains", nargs=-1)
 def generate(domains, version):
+    """
+    Command to read Gandi.net live DNS records and generate
+    corresponding TF gandi_livedns_record resources.
+    """
     if version:
         import importlib.metadata
 
         _version = importlib.metadata.version("gandi-2-terraform")
         click.echo(f"Version {_version}")
         return
+
     commands = []
     for domain in domains:
         content = fetch_records(domain)
